@@ -14,6 +14,7 @@ import json
 import requests
 import dataclasses
 import ayugespidertools.Items
+from typing import Union, List
 from itemadapter import ItemAdapter
 from ayugespidertools.config import logger
 from ayugespidertools.FormatData import DataHandle
@@ -160,7 +161,7 @@ class ToolsForAyu(object):
 
     @classmethod
     @DataHandle.simple_deal_for_extract
-    def extract_with_json(cls, json_data: dict, query: str or list):
+    def extract_with_json(cls, json_data: dict, query: Union[str, List[str]]):
         """
         scrapy 中提取 json 数据遇到的情况
         Args:
@@ -172,15 +173,43 @@ class ToolsForAyu(object):
         """
         # 如果输入的提取规则参数的格式为字符；或者参数格式是个列表，但是只含有一个元素的情况时
         if any([isinstance(query, str), all([isinstance(query, list), len(query) == 1])]):
-            return json_data.get(query, "")
+            if isinstance(query, str):
+                return json_data.get(query, "")
+            return json_data.get(query[0], "")
 
         # 循环取值时的处理
         for curr_q in query:
+
+            # 这里循环时不对 json_data 的类型做判断，如果此时 json_data 类型无 get 方法，不处理
             json_data = json_data.get(curr_q, "")
             if not json_data:
                 return json_data
         return json_data
 
+    @classmethod
+    def extract_with_json_rules(cls, json_data: dict, query_rules: List[Param.Str_Lstr]):
+        """
+        当提取 json 某个数据时，可以在某些字段中取值，只要返回其中任意一个含有数据的值即可
+        Args:
+            json_data: scrapy response 响应内容中的 json 格式数据
+            query_rules: json 提取的规则列表
+
+        Returns:
+            1).提取的内容
+        """
+        # 先判断层级是否为两层
+        depth_num = ReuseOperation.get_array_depth(query_rules)
+        if depth_num > 2:
+            raise Exception("query_rules 参数错误，请输入深度最多为 2 的参数！")
+
+        for query in query_rules:
+            extract_res = cls.extract_with_json(json_data=json_data, query=query)
+
+            # 只要有任意字段存在数据的情况就返回
+            if extract_res:
+                return extract_res
+        return ""
+
     @staticmethod
     def get_collate_by_charset(mysql_config: dict) -> str:
         """
